Home
last modified time | relevance | path

Searched refs:__attribute (Results 1 – 25 of 27) sorted by relevance

12

/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/tsan/rtl/
H A Dtsan_dispatch_defs.h60 # define SANITIZER_WEAK_IMPORT extern "C" __attribute((weak_import))
62 # define SANITIZER_WEAK_IMPORT extern "C" __attribute((weak))
/freebsd-13.1/contrib/libpcap/pcap/
H A Dfuncattrs.h173 #define PCAP_NORETURN __attribute((noreturn))
174 #define PCAP_NORETURN_DEF __attribute((noreturn))
/freebsd-13.1/contrib/llvm-project/clang/lib/Headers/
H A D__clang_cuda_runtime_wrapper.h350 __device__ void free(void *) __attribute((nothrow));
351 __device__ void *malloc(size_t) __attribute((nothrow)) __attribute__((malloc));
/freebsd-13.1/contrib/tcpdump/
H A Dfuncattrs.h78 #define NORETURN __attribute((noreturn))
H A Dconfigure3660 main(int argc __attribute((unused)), char **argv __attribute((unused)))
/freebsd-13.1/crypto/openssl/crypto/modes/
H A Dofb128.c15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
H A Dctr128.c15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
H A Dcbc128.c19 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
H A Dxts128.c16 typedef u64 u64_a1 __attribute((__aligned__(1))); typedef
H A Dcfb128.c15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
H A Dmodes_local.h42 typedef u32 u32_a1 __attribute((__aligned__(1))); typedef
H A Dccm128.c16 typedef u64 u64_a1 __attribute((__aligned__(1))); typedef
H A Dgcm128.c15 typedef size_t size_t_aX __attribute((__aligned__(1))); typedef
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/hwasan/
H A Dhwasan_dynamic_shadow.cpp86 extern __attribute((weak, visibility("hidden"))) ElfW(Rela) __rela_iplt_start[],
/freebsd-13.1/contrib/llvm-project/compiler-rt/lib/profile/
H A DInstrProfilingPort.h39 #define COMPILER_RT_ALWAYS_INLINE inline __attribute((always_inline))
/freebsd-13.1/sbin/routed/rtquery/
H A Drtquery.c129 static void trace_loop(char *argv[]) __attribute((__noreturn__));
130 static void query_loop(char *argv[], int) __attribute((__noreturn__));
/freebsd-13.1/crypto/openssl/crypto/aes/
H A Daes_ige.c26 } aes_block_t __attribute((__aligned__(1))); typedef
/freebsd-13.1/crypto/openssl/crypto/whrlpool/
H A Dwp_block.c68 typedef u64 u64_a1 __attribute((__aligned__(1))); typedef
75 typedef u64 u64_aX __attribute((__aligned__(1))); typedef
/freebsd-13.1/sys/contrib/octeon-sdk/
H A Dcvmx-debug.c115 static char cvmx_debug_stack[8*1024] __attribute ((aligned (16)));
133 static char cvmx_debug_stack_all[CVMX_MAX_CORES][8*1024] __attribute ((aligned (16)));
/freebsd-13.1/contrib/llvm-project/llvm/include/llvm/ADT/
H A DStringRef.h902 __attribute((enable_if(__builtin_strlen(Str) == N - 1, in StringLiteral()
/freebsd-13.1/contrib/llvm-project/clang/include/clang/Basic/
H A DTokenKinds.def427 KEYWORD(__attribute , KEYALL)
632 ALIAS("__attribute__", __attribute, KEYALL)
/freebsd-13.1/crypto/openssl/crypto/ec/
H A Decp_nistp224.c75 typedef uint64_t limb_aX __attribute((__aligned__(1)));
H A Decp_nistz256.c35 # define ALIGN32 __attribute((aligned(32)))
H A Decp_nistp521.c131 typedef limb limb_aX __attribute((__aligned__(1)));
H A Decp_nistz256_table.c25 __attribute((aligned(4096)))

12